@@ -8,18 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.aws_sns._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-fargate-sns",
-    "1.153.0",
+    "2.3.0",
     __name__[0:-6],
-    "aws-fargate-sns@1.153.0.jsii.tgz",
+    "aws-fargate-sns@2.3.0.jsii.tgz",
 )
 
 __all__ = [
